#!/bin/bash

here=`pwd`

training(){
    training.perl --first-step 0 --last-step 6 \
	--train-src $here/data/newsco.fr \
	--train-trg $here/data/newsco.en \
	--train-src-rules $here/data/newsco.fr.pos \
	--train-src-bm $here/data/newsco.fr \
	--train-trg-bm $here/data/newsco.en \
	--name-src-bm w \
	--name-trg-bm w \
	--alignment-file $here/data/newsco.fr2en.ali \
	--output-dir $here/fr2en
    
    training.perl --first-step 4 --last-step 4 \
	--train-src-bm $here/data/newsco.fr.pos \
	--train-trg-bm $here/data/newsco.en.pos \
	--name-src-bm p \
	--name-trg-bm p \
	--output-dir $here/fr2en

    $SRILM/ngram-count -text $here/data/newsco.en -lm $here/fr2en/newsco.en.3guki.lm -order 3 -unk -kndiscount -interpolate
    $KENLM/build_binary -trie $here/fr2en/newsco.en.3guki.lm  $here/fr2en/newsco.en.3guki.lm.mmap
}

optimization(){
    binrules -maxc 4 -maxr 9 \
	-wrd $here/data/test2009.fr \
	-tag $here/data/test2009.fr.pos \
	-rrules $here/fr2en/posrules.max10.smooth0.. \
	> $here/data/test2009.fr.rrules.maxc4.maxr9
    
    cat $here/data/test2009.fr.rrules.maxc4.maxr9 | binfiltr -maxs 5 \
	-tunits $here/fr2en/unfold.maxs5.maxf4.tnb30.voc \
	-scores $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.lex1.lex2.rfreq1.rfreq2 \
	-lexrm $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.msdcfb \
	-bilfactor $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.w-w.bil.factor \
	-bilfactor $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.p-p.bil.factor \
	-trgfactor $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.w-w.trg.factor \
	> $here/data/test2009.fr.rrules.maxc4.maxr9.filtered.maxs5.bww.bpp.tww
    
    tlmww=$here/fr2en/newsco.en.3guki.lm.mmap
    blmww=$here/fr2en/unfold.maxs5.maxf4.tnb30.voc.w-w.bil.-order_3_-unk_-gt3min_1_-kndiscount_-interpolate.lm.mmap
    blmpp=$here/fr2en/unfold.maxs5.maxf4.tnb30.voc.p-p.bil.-order_3_-unk_-gt3min_1_-kndiscount_-interpolate.lm.mmap
    optdir=$here/fr2en/mert.blmww.tlmww.msd
    flags="-blm0 0,$blmww -tlm0 0,6,$tlmww -b 25 -threads 4"
    lambdas="lb0:1 lt0:1 lp0:1 lp1:1 ld:1 la0:1 la1:1 la2:1 la3:1 lmc:1 lsc:1 ldc:1 lmp:1 lsp:1 ldp:1"
    
    mert-run.perl --working-dir=$optdir \
	--input=$here/data/test2009.fr.rrules.maxc4.maxr9.filtered.maxs5.bww.bpp.tww \
	--refs=$here/data/test2009.en \
	--decoder-flags="$flags" \
	--lambdas="$lambdas" \
	--nbest=300 &> $optdir.log
} 
    
testing(){
    binrules -maxc 4 -maxr 9 \
	-wrd $here/data/test2010.fr \
	-tag $here/data/test2010.fr.pos \
	-rrules $here/fr2en/posrules.max10.smooth0.. \
	> $here/data/test2010.fr.rrules.maxc4.maxr9
    
    cat $here/data/test2010.fr.rrules.maxc4.maxr9 | binfiltr -maxs 5 \
	-tunits $here/fr2en/unfold.maxs5.maxf4.tnb30.voc \
	-scores $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.lex1.lex2.rfreq1.rfreq2 \
	-lexrm $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.msdcfb \
	-bilfactor $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.w-w.bil.factor \
	-bilfactor $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.p-p.bil.factor \
	-trgfactor $here/fr2en/unfold.maxs5.maxf4.tnb30.voc.w-w.trg.factor \
	> $here/data/test2010.fr.rrules.maxc4.maxr9.filtered.maxs5.bww.bpp.tww
    
    mert-tst.perl -optimal $optdir.log \
	-i $here/data/test2010.fr.rrules.maxc4.maxr9.filtered.maxs5.bww.bpp.tww \
	-o $optdir/out.test2010 \
	-run 
    
    evaluate.perl -tst $optdir/out.test2010 -ref $here/data/test2010.en -b 
}

#uncomment to run each section!
### training &> log.training 
### optimization &> log.optimization
### testing &> log.testing